@@ -6,12 +6,12 @@
 
 
 /*
- * $Id: slog.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: slog.h,v 1.2 2003/03/09 19:29:21 steveg Exp $
  */
 #ifndef __SLOG_H
 #define __SLOG_H
 
-struct syslog
+struct syslog_s
 {
 	int sl_facility ;
 	int sl_default_level ;
@@ -27,7 +27,7 @@ struct syslog_parms
    /* bool_int slp_ident_is_malloced ; */
 } ;
 
-#define SYSLOG( xp )         ((struct syslog *)xp->xl_data)
+#define SYSLOG( xp )         ((struct syslog_s *)xp->xl_data)
 
 #endif
 
