@@ -9,7 +9,7 @@
 #define ATTR_H
 
 /*
- * $Id: attr.h,v 1.2 1999/10/13 02:51:03 bbraun Exp $
+ * $Id: attr.h,v 1.1.1.1 2003/02/19 17:29:27 bbraun Exp $
  */
 
 /*
@@ -57,26 +57,24 @@
 #define A_V6ONLY           39
 #define A_DENY_TIME        40
 #define A_UMASK            41
+#define A_ENABLED          42
+#define A_DISABLED         43
 
 /*
  * SERVICE_ATTRIBUTES is the number of service attributes and also
  * the number from which defaults-only attributes start.
  */
-#define SERVICE_ATTRIBUTES      ( A_CPS + 1 )
-
-#define A_DISABLED              ( SERVICE_ATTRIBUTES )
-#define A_ENABLED               ( A_DISABLED + 1 )
-
+#define SERVICE_ATTRIBUTES      ( A_ENABLED + 1 )
 
 /*
  * Mask of attributes that must be specified.
  */
 #define NECESSARY_ATTRS         ( XMASK( A_SOCKET_TYPE ) + XMASK( A_WAIT ) )
-
-#define NECESSARY_ATTRS_EXTERNAL     XMASK( A_SERVER )
-#define NECESSARY_ATTRS_RPC_LISTED   XMASK( A_PROTOCOL )
-#define NECESSARY_ATTRS_RPC_UNLISTED XMASK( A_PROTOCOL ) + XMASK( A_RPC_NUMBER )
-#define NECESSARY_ATTRS_LISTED       XMASK( A_USER )
+#define NECESSARY_ATTRS_EXTERNAL     ( XMASK( A_SERVER ) + XMASK( A_USER ) )
 #define NECESSARY_ATTRS_UNLISTED     ( XMASK( A_PROTOCOL ) + XMASK( A_PORT ) )
+#define NECESSARY_ATTRS_UNLISTED_MUX ( XMASK( A_PROTOCOL ) )
+#define NECESSARY_ATTRS_RPC          ( XMASK( A_PROTOCOL ) + \
+                                       XMASK( A_RPC_VERSION ) )
+#define NECESSARY_ATTRS_RPC_UNLISTED XMASK( A_RPC_NUMBER )
 
 #endif   /* ATTR_H */
