@@ -106,7 +106,7 @@ void int_init( struct intercept_s *ip, struct server *serp )
 
       if ( sp == SERVER_SERVICE( serp ) )
          continue ;
-      if ( log_get_type( SC_LOG( SVC_CONF( sp ) ) ) == L_FILE )
+      if ( LOG_GET_TYPE( SC_LOG( SVC_CONF( sp ) ) ) == L_FILE )
          xlog_destroy( sp->svc_log ) ;
       (void) close( SVC_FD( sp ) ) ;
    }
