@@ -66,7 +66,15 @@ void dump_internal_state(void)
       return ;
    }
    
-   Sbuftype( dump_fd, SIO_LINEBUF ) ;
+   if (Sbuftype( dump_fd, SIO_LINEBUF ) == SIO_ERR )
+   {
+       /*
+	* If the above function failed, Sprint will most likely
+	* fail, too. Output a message for troubleshooting and quit.
+	*/
+       msg( LOG_ERR, func, "failed setting up sio buffering: %m" ) ;
+       return;
+   }
 
    /*
     * Print the program name, version, and timestamp.
@@ -137,7 +145,7 @@ void dump_internal_state(void)
    Sputchar( dump_fd, '\n' ) ;
 
    Sprint( dump_fd, "END OF DUMP\n\n" ) ;
-   Sclose( dump_fd ) ;
+   Sclose( dump_fd );
 
    msg( LOG_INFO, func, "generated state dump in file %s", dump_file ) ;
 }
@@ -238,7 +246,7 @@ static void consistency_check( enum check_type type )
     * Check if there are any descriptors set in socket_mask_copy
     */
    for ( fd = 0 ; fd < ps.ros.max_descriptors ; fd++ )
-      if ( FD_ISSET( fd, &socket_mask_copy ) )
+      if ( FD_ISSET( fd, &socket_mask_copy ) && ((fd != signals_pending[0]) && fd != signals_pending[1]))
       {
          msg( LOG_ERR, func,
             "descriptor %d set in socket mask but there is no service for it",
