@@ -5,25 +5,25 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: msg.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
 #include "config.h"
 #include <syslog.h>
 #include <fcntl.h>
 #include <stdarg.h>
+#include <unistd.h>
 
-#include "sio.h"
-#include "str.h"
 #include "xlog.h"
-
-#include "options.h"
-
-#include "state.h"
+#include "str.h"
+#include "msg.h"
 #include "defs.h"
+#include "options.h"
 #include "xconfig.h"
+#include "util.h"
+#include "nvlists.h"
+#include "main.h"
+#include "parse.h"
 
-
-static struct name_value priorities[] =
+static const struct name_value priorities[] =
    {
       { "WARNING",   LOG_WARNING  },
       { "ERROR",     LOG_ERR      },
@@ -35,21 +35,17 @@ static struct name_value priorities[] =
       { "UNKNOWN",   0            }
    } ;
 
-
-extern int line_count ;
-extern struct name_value syslog_facilities[] ;
-
 #define BUFSIZE                     2048
 
 #define DEFAULT_SYSLOG_LEVEL         LOG_INFO
 
-char *msg_init()
+char *msg_init(void)
 {
    xlog_h      xh ;
    int         fd ;
    xlog_e      type_of_xlog ;
    bool_int    facility_error = FALSE ;
-   char        *func            = "msg_init" ;
+   const char *func            = "msg_init" ;
 
    if ( debug.on )
    {
@@ -73,7 +69,7 @@ char *msg_init()
          
          if ( syslog_option )
          {
-            struct name_value *nvp ;
+            const struct name_value *nvp ;
 
             nvp = nv_find_value( syslog_facilities, syslog_option_arg ) ;
             if ( nvp != NULL )
@@ -111,7 +107,7 @@ char *msg_init()
    if ( type_of_xlog == XLOG_FILELOG &&
             xlog_control( xh, XLOG_GETFD, &fd ) == XLOG_ENOERROR )
    {
-      if ( fcntl( fd, F_SETFD, 1 ) == -1 )
+      if ( fcntl( fd, F_SETFD, FD_CLOEXEC ) == -1 )
       {
          xlog_destroy( xh ) ;
          return( "can't set close-on-exec flag of log file" ) ;
@@ -128,13 +124,13 @@ char *msg_init()
 }
 
 
-void msg_suspend()
+void msg_suspend(void)
 {
    (void) xlog_control( ps.rws.program_log, XLOG_PREEXEC ) ;
 }
 
 
-void msg_resume()
+void msg_resume(void)
 {
    (void) xlog_control( ps.rws.program_log, XLOG_POSTEXEC ) ;
 }
@@ -143,12 +139,16 @@ void msg_resume()
 /*
  * The size argument is a value-result argument
  */
-PRIVATE int prepare_buffer( int level, 
-                            char *func, 
-                            char *buf, 
-                            unsigned size, 
-                            char *fmt, 
-                            va_list ap )
+static int
+#ifdef __GNUC__
+__attribute__ ((format (printf, 5, 0)))
+#endif
+prepare_buffer( int level, 
+                const char *func, 
+                char *buf, 
+                unsigned size, 
+                const char *fmt, 
+                va_list ap )
 {
    int         cc ;
    char        *bufstart   = buf ;
@@ -170,7 +170,7 @@ PRIVATE int prepare_buffer( int level,
     */
    if ( debug.on || level == LOG_CRIT )
    {
-      cc = strx_nprint( bufstart, bytes_left, "{%s} ", func ) ;
+      cc = strx_nprint( bufstart, bytes_left, "%d {%s} ", getpid(), func ) ;
       bufstart += cc ;
       bytes_left -= cc ;
    }
@@ -184,7 +184,7 @@ PRIVATE int prepare_buffer( int level,
 
 
 /* VARARGS3 */
-void msg( int level, char *func, char *fmt, ...)
+void msg( int level, const char *func, const char *fmt, ...)
 {
    va_list   ap ;
    char      buf[ BUFSIZE ] ;
@@ -205,7 +205,7 @@ void msg( int level, char *func, char *fmt, ...)
  *      2) parsemsg() does not interpret %m
  */
 /* VARARGS3 */
-void parsemsg( int msg_level, char *func, char *fmt, ...)
+void parsemsg( int msg_level, const char *func, const char *fmt, ...)
 {
    va_list   ap ;
    char      buf[ BUFSIZE ] ;
